==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/en-ID/admin/custom_fields/message.php <==
<?php

return array(

    'field' => array(
        'invalid'   => 'Bidang tersebut tidak tersedia.',
        'already_added'   => 'Bidang sudah ditambahkan',

        'create' => array(
            'error'   => 'Bidang gagal dibuat, silahkan coba lagi.',
            'success' => 'Kategori Berhasil dibuat.',
            'assoc_success' => 'Kategori berhasil ditambahkan ke fieldset.'
        ),

        'update' => array(
            'error'   => 'Kategori gagal diupdate, silahkan coba lagi',
            'success' => 'Kategori Berhasil dibuat.'
        ),

        'delete' => array(
            'confirm'   	=> 'Apakah Anda yakin ingin menghapus kategori ini?',
            'error'   => 'Terjadi masalah saat menghapus kategori. Silahkan coba lagi.',
            'success' => 'Kategori berhasil dihapus.',
            'in_use'   => 'Kategori masih digunakan.',
        )

    ),

    'fieldset' => array(

        'does_not_exist' => 'Kategori tidak ada',

        'create' => array(
            'error'   => 'Kategori gagal dibuat, silahkan coba lagi.',
            'success' => 'Kategori Berhasil dibuat.'
        ),

        'update' => array(
            'error'   => 'Kategori gagal diupdate, silahkan coba lagi',
            'success' => 'Kategori Berhasil diperbarui.'
        ),

        'delete' => array(
            'confirm'   	=> 'Apakah Anda yakin ingin menghapus kategori ini?',
            'error'   => 'Terjadi masalah saat menghapus kategori. Silahkan coba lagi.',
            'success' => 'Kategori berhasil dihapus.',
            'in_use'   => 'Kategori masih digunakan.',
        )

    ),






);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/en-ID/admin/custom_fields/message.php <==
<?php

return array(

    'field' => array(
        'invalid'   => 'Bidang tersebut tidak tersedia.',
        'already_added'   => 'Bidang sudah ditambahkan',
        'none_selected'   => 'No field selected',

        'create' => array(
            'error'   => 'Bidang gagal dibuat, silahkan coba lagi.',
            'success' => 'Kategori Berhasil dibuat.',
            'assoc_success' => 'Kategori berhasil ditambahkan ke fieldset.'
        ),

        'update' => array(
            'error'   => 'Kategori gagal diupdate, silahkan coba lagi',
            'success' => 'Kategori Berhasil dibuat.'
        ),

        'delete' => array(
            'confirm'   	=> 'Apakah Anda yakin ingin menghapus kategori ini?',
            'error'   => 'Terjadi masalah saat menghapus kategori. Silahkan coba lagi.',
            'success' => 'Kategori berhasil dihapus.',
            'in_use'   => 'Kategori masih digunakan.',
        )

    ),

    'fieldset' => array(

        'does_not_exist' => 'Kategori tidak ada',

        'create' => array(
            'error'   => 'Kategori gagal dibuat, silahkan coba lagi.',
            'success' => 'Kategori Berhasil dibuat.'
        ),

        'update' => array(
            'error'   => 'Kategori gagal diupdate, silahkan coba lagi',
            'success' => 'Kategori Berhasil diperbarui.'
        ),

        'delete' => array(
            'confirm'   	=> 'Apakah Anda yakin ingin menghapus kategori ini?',
            'error'   => 'Terjadi masalah saat menghapus kategori. Silahkan coba lagi.',
            'success' => 'Kategori berhasil dihapus.',
            'in_use'   => 'Kategori masih digunakan.',
        )

    ),

    'fieldset_default_value' => array(

        'error' => 'Error validating default fieldset values.',

    ),






);
